/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88e                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for R32C eval boards
--------  END-OF-HEADER  ---------------------------------------------
*/

#define BSP_C
#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs used here **********************************************/

#define P4      (*(volatile unsigned char*)  (0x000003C8))
#define PD4     (*(volatile unsigned char*)  (0x000003CA))

/****** Target specific configuration *******************************/

#define LEDPORT       P4
#define LEDPORT_DIR   PD4

/****** Assign LEDs to Ports ****************************************/

#define LED_ACTIVE_HIGH (1)   // Define as 0, if LEDs are switched on with low level on port

#define LED0_BIT        (0)
#define LED1_BIT        (1)
#define LED2_BIT        (2)
#define LED3_BIT        (3)

#define LED0_MASK       (1uL << LED0_BIT)
#define LED1_MASK       (1uL << LED1_BIT)
#define LED2_MASK       (1uL << LED2_BIT)
#define LED3_MASK       (1uL << LED3_BIT)

#define LEDMASK_ALL   (LED0_MASK | LED1_MASK | LED2_MASK | LED3_MASK)

#if LED_ACTIVE_HIGH
  #define LED_ON(Index)   (LEDPORT |=  (1uL << (Index + LED0_BIT)))
  #define LED_OFF(Index)  (LEDPORT &= ~(1uL << (Index + LED0_BIT)))
  #define LED_ALLON()     (LEDPORT |=  LEDMASK_ALL)
  #define LED_ALLOFF()    (LEDPORT &= ~LEDMASK_ALL)
#else
  #define LED_ON(Index)   (LEDPORT &= ~(1uL << (Index + LED0_BIT)))
  #define LED_OFF(Index)  (LEDPORT |=  (1uL << (Index + LED0_BIT)))
  #define LED_ALLON()     (LEDPORT &= ~LEDMASK_ALL)
  #define LED_ALLOFF()    (LEDPORT |=  LEDMASK_ALL)
#endif

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       LED_Init()
*/
void BSP_Init(void) {
  LEDPORT_DIR = LEDMASK_ALL;           /* Enable Port as output */
  //
  // Initially clear LEDs
  //
  LED_ALLOFF();
}

/*********************************************************************
*
*       LED switching routines
*/
void BSP_SetLED(int Index) {
  LED_ON(Index);
}

void BSP_ClrLED(int Index) {
  LED_OFF(Index);
}

void BSP_ToggleLED(int Index) {
  LEDPORT ^= (1 << (Index + LED0_BIT));
}

/****** End of file *************************************************/


